<?php

class Chronopost_Food_Helper_Data extends Mage_Core_Helper_Abstract {
    //Choronorelais settings for productCode
    const CHRONO_FRESH = '2R'; // for France
    const CHRONO_FRESH_STR = '13H'; // for France

    const CHRONOPOST_DEFAULT_COUNTRY = 'FR';
    const CHRONOPOST_TRACKING_URL = 'http://wsshipping.chronopost.fr/shipping/services/getReservedSkybill?reservationNumber={trackingNumber}';

    const CHRONOFRESH_SMD = '2P'; // for Chronopost SAMEDAY
    const CHRONOFRESH_SMD_STR = 'SMD'; // for Chronopost SAMEDAY

    const CHRONOFRESH_SRDV = '2E';
    const CHRONOFRESH_SRDV_STR = 'SRDV'; // for Chronopost Sur Rendez-vous

    // if you are in a period outside thursday 18:00 to friday 15:00, there is no shipping on saturday
    var $SaturdayShippingDays = array(
        'startday' => 'thursday',
        'endday' => 'friday',
        'starttime' => '18:00:00',
        'endtime' => '15:00:00'
    );

    public function getConfigData($path) {
        return Mage::getStoreConfig($path, Mage::app()->getStore());
    }

    public function getSaturdayShippingDays() {

        $starday = explode(":",$this->getConfigData("food/saturday/startday"));
        $endday = explode(":",$this->getConfigData("food/saturday/endday"));

        $saturdayDays = array();
        $saturdayDays['startday'] = (count($starday) == 3 && isset($starday[0])) ? $starday[0] : $this->SaturdayShippingDays['startday'];
        $saturdayDays['starttime'] = (count($starday) == 3 && isset($starday[1])) ? $starday[1].':'.$starday[2].':00' : $this->SaturdayShippingDays['starttime'];
        $saturdayDays['endday'] = (count($endday) == 3 && isset($endday[0])) ? $endday[0] : $this->SaturdayShippingDays['endday'];
        $saturdayDays['endtime'] = (count($endday) == 3 && isset($endday[1])) ? $endday[1].':'.$endday[2].':00' : $this->SaturdayShippingDays['endtime'];

        return $saturdayDays;
    }

    public function getCurrentTimeByZone($timezone="Europe/Paris", $format="l H:i") {
        $d = new DateTime("now", new DateTimeZone($timezone));
        return $d->format($format);
    }

    public function isSendingDay() {
        $shipping_days = $this->getSaturdayShippingDays();
        $current_day = strtolower($this->getCurrentTimeByZone("Europe/Paris", "l"));
        $current_date = $this->getCurrentTimeByZone("Europe/Paris", "Y-m-d H:i:s");
        $current_datetime = explode(' ', $current_date);

        //get timestamps
        $start_timestamp = strtotime($current_datetime[0] . " " . $shipping_days['starttime']);
        $end_timestamp = strtotime($current_datetime[0] . " " . $shipping_days['endtime']);
        $current_timestamp = strtotime($current_date);

        $sending_day = false;
        /*if (  ($shipping_days['startday'] == $current_day && $current_timestamp >= $start_timestamp) || ($shipping_days['endday'] == $current_day && $current_timestamp <= $end_timestamp)  ) {
            $sending_day = true;
        }*/
        if (  $current_timestamp >= $start_timestamp && $current_timestamp <= $end_timestamp  ) {
            $sending_day = true;
        }
        return $sending_day;
    }

    /**
     * General Shipping configuration
     */
    public function getConfigurationAccountNumber() {
        return $this->getConfigData('food/shipping/account_number');
    }

    public function getConfigurationSubAccountNumber() {
        return $this->getConfigData('food/shipping/sub_account_number');
    }

    public function getConfigurationAccountPass() {
        return $this->getConfigData('food/shipping/account_pass');
    }

    public function getConfigurationTrackingViewUrl() {
        return $this->getConfigData('food/shipping/tracking_view_url');
    }

    public function getConfigurationGoogleMapAPIKey() {
        return $this->getConfigData('food/shipping/google_map_api');
    }

    public function getChronoProductCode($country, $code='') {
        $productcode = '';
        $code = strtolower($code);

        switch($code) {
            case 'chronofresh' :
                $productcode = static::CHRONO_FRESH;
                break;
            case 'chronofreshsameday' :
                $productcode = static::CHRONOFRESH_SMD;
                break;
            case 'chronofreshsrdv' :
                $productcode = static::CHRONOFRESH_SRDV;
                break;
            default :
                $productcode = static::CHRONO_FRESH;
                break;
        }
        return $productcode;
    }

    public function getChronoProductCodeToShipment($code='') {
        $productcode = '';
        $code = strtolower($code);

        switch($code) {
            case 'chronofresh' :
                $productcode = static::CHRONO_FRESH;
                break;
            case 'chronofreshsameday' :
                $productcode = static::CHRONOFRESH_SMD;
                break;
            case 'chronofreshsrdv' :
                $productcode = static::CHRONOFRESH_SRDV;
                break;
            default :
                $productcode = static::CHRONO_FRESH;
                break;
        }
        return $productcode;
    }

    public function getChronoProductCodeString($code='') {
        $productcode = '';
        $code = strtolower($code);

        switch($code) {
            case 'chronofresh' :
                $productcode = static::CHRONO_FRESH_STR;
                break;
            case 'chronofreshsameday' :
                $productcode = static::CHRONOFRESH_SMD_STR;
                break;
            case 'chronofreshsrdv' :
                $productcode = static::CHRONOFRESH_SRDV_STR;
                break;
            default :
                $productcode = static::CHRONO_FRESH_STR;
                break;
        }
        return $productcode;
    }

    public function getConfigurationTrackingUrl() {
        return static::CHRONOPOST_TRACKING_URL;
    }

    /**
     * Export configuration
     */
    public function getConfigurationFileExtension($export_type='css') {
        return $this->getConfigData('food/export_' . $export_type . '/file_extension');
    }

    public function getConfigurationFileCharset($export_type='css') {
        return $this->getConfigData('food/export_' . $export_type . '/file_charset');
    }

    public function getConfigurationEndOfLineCharacter($export_type='css') {
        return $this->getConfigData('food/export_' . $export_type . '/endofline_character');
    }

    public function getConfigurationFieldDelimiter($export_type='css') {
        return $this->getConfigData('food/export_' . $export_type . '/field_delimiter');
    }

    public function getConfigurationFieldSeparator($export_type='css') {
        return $this->getConfigData('food/export_' . $export_type . '/field_separator');
    }

    /**
     * Import configuration
     */
    public function getConfigurationSendEmail() {
        return $this->getConfigData('food/import/send_email');
    }

    public function getConfigurationIncludeComment() {
        return $this->getConfigData('food/import/include_comment');
    }

    public function getConfigurationDefaultTrackingTitle() {
        return $this->getConfigData('food/import/default_tracking_title');
    }

    public function getConfigurationShippingComment() {
        return $this->getConfigData('food/import/shipping_comment');
    }

    /**
     * Shipper Information
     */
    public function getConfigurationShipperInfo($field) {
        $fieldValue = '';
        if ($field && $this->getConfigData('food/shipperinformation/' . $field)) {
            $fieldValue = $this->getConfigData('food/shipperinformation/' . $field);
        }
        return $fieldValue;
    }

    /**
     * Chronopost Customer Information
     */
    public function getConfigurationCustomerInfo($field) {
        $fieldValue = '';
        if ($field && $this->getConfigData('food/customerinformation/' . $field)) {
            $fieldValue = $this->getConfigData('food/customerinformation/' . $field);
        }
        return $fieldValue;
    }

    /**
     * Import configuration
     */
    public function getConfigurationSkybillParam() {
        return $this->getConfigData('food/skybillparam/mode');
    }

    /*
     * Weight unit
     */
    public function getConfigWeightUnit() {
        return $this->getConfigData('food/weightunit/unit');
    }

    /* Get Livraison le Samedi status by orderid */

    public function getLivraisonSamediStatus($order_id) {
        $_connection = Mage::getSingleton('core/resource')->getConnection('core_write');
        $_table = Mage::getSingleton('core/resource')->getTableName('sales_chronofood_order_export_status');
        $select = $_connection->select()
            ->from($_table, 'livraison_le_samedi')
            ->where('order_id=?', $order_id);
        $status = $_connection->fetchOne($select);
        return $status;
    }


    /*
     * Return true si la méthode de livraison fait partie du contrat du marchant
     */
    public function shippingMethodEnabled($shippingMethod) {
        return true;
    }

    /*
    * Return true if we can show google map
    */
    public function canShowGoogleMap() {
        return $this->getConfigData('carriers/food/show_google_map');
    }

    /* return track number field name */
    public function getTrackNumberFieldName() {
        if (version_compare(Mage::getVersion(), '1.5.1.0', '>')) {
            return "track_number";
        } else {
            return "number";
        }

    }

    public function addMargeToQuickcost($quickcost_val,$carrierCode = '', $firstPassage = true) {
        if($carrierCode) {

            $quickcostMarge = Mage::getStoreConfig('carriers/' . $carrierCode . '/quickcost_marge');
            $quickcostMargeType = Mage::getStoreConfig('carriers/' . $carrierCode . '/quickcost_marge_type');

            if($quickcostMarge) {
                if($quickcostMargeType == 'amount') {
                    $quickcost_val += $quickcostMarge;
                } elseif($quickcostMargeType == 'prcent') {
                    $quickcost_val += $quickcost_val * $quickcostMarge / 100;
                }
            }
        }

        return $quickcost_val;
    }

    /**
     * Fetch expiration date for given order
     * @param Mage_Sales_Model_Order $order
     * @return false|null|string
     */
    public function getOrderExpirationDate(Mage_Sales_Model_Order $order) {
        $_connection = Mage::getSingleton('core/resource')->getConnection('core_read');
        $_table = Mage::getSingleton('core/resource')->getTableName('sales_chronofood_order_dlc');
        $select = $_connection->select()
            ->from($_table, 'dlc')
            ->where('order_id=?', $order->getId());
        $dlc = $_connection->fetchOne($select);
        if ($dlc) {
            $dlcFormat = date( "d/m/Y" , $dlc);
        } else {
            $dlcFormat = '';
        }

        return $dlcFormat;
    }

}
