<?php

class Chronopost_Food_Helper_Webservice extends Mage_Core_Helper_Abstract {

    var $methodsAllowed = false;


     public function checkLogin($quickCost,$quickcost_url = '') {
        if (!$quickcost_url) {
            $quickcost_url = "https://www.chronopost.fr/quickcost-cxf/QuickcostServiceWS?wsdl";
        }
        try {
            $client = new SoapClient($quickcost_url);
            $webservbt = $client->calculateProducts($quickCost);
            return $webservbt;
        } catch (Exception $e) {
            return false;
        }
    }

    /*
     * Return true si la méthode de livraison fait partie du contrat
     */
    public function getMethodIsAllowed($code,$quote = '') {
        $quote = Mage::getSingleton('checkout/cart')->getQuote();
        $address = $quote->getShippingAddress();
        $helperData = Mage::helper('food');
        $code = $helperData->getChronoProductCode('',$code);
        try {
            if($this->methodsAllowed === false) {
                $this->methodsAllowed = array();
                $client = new SoapClient("https://www.chronopost.fr/quickcost-cxf/QuickcostServiceWS?wsdl", array('trace' => 0, 'connection_timeout' => 10));
                $params = array(
                    'accountNumber' => $helperData->getConfigurationAccountNumber(),
                    'password' => $helperData->getConfigurationAccountPass(),
                    'depCountryCode' => $helperData->getConfigurationShipperInfo('country'),
                    'depZipCode' => $helperData->getConfigurationShipperInfo('zipcode'),
                    'arrCountryCode' => $this->getFilledValue($address->getCountryId()),
                    'arrZipCode' => $this->getFilledValue($address->getPostcode()),
                    'arrCity' => $address->getCity() ? $this->getFilledValue($address->getCity()) : '-',
                    'type' => 'M',
                    'weight' => 1
                );
                $webservbt = $client->calculateProducts($params);
                if($webservbt->return->errorCode == 0 && $webservbt->return->productList)
                {
                    if(is_array($webservbt->return->productList)) {
                      foreach($webservbt->return->productList as $product) {
                          $this->methodsAllowed[] = $product->productCode;
                      }
                    } else { /* cas ou il y a un seul résultat */
                      $product = $webservbt->return->productList;
                      $this->methodsAllowed[] = $product->productCode;
                    }
                }
            }
            if(!empty($this->methodsAllowed) && in_array($code, $this->methodsAllowed)) {
                return true;
            }
            return false;
        }catch(Exception $e) {
            return false;
        }
    }


    public function getFilledValue($value) {
        if ($value) {
            return $this->removeaccents(trim($value));
        } else {
            return '';
        }
    }

    public function removeaccents($string) {
        $stringToReturn = str_replace(
                array('à', 'á', 'â', 'ã', 'ä', 'ç', 'è', 'é', 'ê', 'ë', 'ì', 'í', 'î', 'ï', 'ñ', 'ò', 'ó', 'ô', 'õ', 'ö', 'ù', 'ú', 'û', 'ü', 'ý', 'ÿ', 'À', 'Á', 'Â', 'Ã', 'Ä', 'Ç', 'È', 'É', 'Ê', 'Ë', 'Ì', 'Í', 'Î', 'Ï', 'Ñ', 'Ò', 'Ó', 'Ô', 'Õ', 'Ö', 'Ù', 'Ú', 'Û', 'Ü', 'Ý', '/', '\xa8'), array('a', 'a', 'a', 'a', 'a', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i', 'n', 'o', 'o', 'o', 'o', 'o', 'u', 'u', 'u', 'u', 'y', 'y', 'A', 'A', 'A', 'A', 'A', 'C', 'E', 'E', 'E', 'E', 'I', 'I', 'I', 'I', 'N', 'O', 'O', 'O', 'O', 'O', 'U', 'U', 'U', 'U', 'Y', ' ', 'e'), $string);
        // Remove all remaining other unknown characters
        $stringToReturn = preg_replace('/[^a-zA-Z0-9\-]/', ' ', $stringToReturn);
        $stringToReturn = preg_replace('/^[\-]+/', '', $stringToReturn);
        $stringToReturn = preg_replace('/[\-]+$/', '', $stringToReturn);
        $stringToReturn = preg_replace('/[\-]{2,}/', ' ', $stringToReturn);
        return $stringToReturn;
    }

    public function cancelSkybill($skybillNumber = '') {
        if($skybillNumber) {
            try {

                $client = new SoapClient("https://www.chronopost.fr/tracking-cxf/TrackingServiceWS?wsdl",array('trace'=> 0,'connection_timeout'=>10));

                $helperData = Mage::helper('food');
                $params = array(
                    'accountNumber' => $helperData->getConfigurationAccountNumber(),
                    'password' => $helperData->getConfigurationAccountPass(),
                    'skybillNumber' => $skybillNumber,
                    'language' => Mage::app()->getLocale()->getLocaleCode()
                );

                return $client->cancelSkybill($params);
            }  catch (Exception $e) {
                return false;
            }
        }
        return false;
    }

    /* Livraison sur rendez-vous */
    public function getSearchDeliverySlot($_srdvConfig = '') {
        $quote = Mage::getSingleton('checkout/cart')->getQuote();

        $_shippingAddress = $quote->getShippingAddress();
        $recipient_address = $_shippingAddress->getStreet();
        if (!isset($recipient_address[1])) {
            $recipient_address[1] = '';
        }

        $_helper = Mage::helper('food');
        try {

            $soapHeaders = array();
            $namespace = 'http://cxf.soap.ws.creneau.chronopost.fr/';
            $soapHeaders[] = new SoapHeader($namespace, 'password', $_helper->getConfigurationAccountPass());
            $soapHeaders[] = new SoapHeader($namespace, 'accountNumber', $_helper->getConfigurationAccountNumber());

            $client = new SoapClient("https://www.chronopost.fr/rdv-cxf/services/CreneauServiceWS?wsdl", array('trace' => 1, 'connection_timeout' => 10));
            $client->__setSoapHeaders($soapHeaders);

            $_srdvConfig = json_decode($_srdvConfig,true);

            /* definition date de debut */
            $dateBegin = date('Y-m-d H:i:s');
            if(isset($_srdvConfig['dateRemiseColis_nbJour']) && $_srdvConfig['dateRemiseColis_nbJour'] > 0) {
                $dateBegin =  date('Y-m-d', strtotime('+'.(int)$_srdvConfig['dateRemiseColis_nbJour'].' day'));
            } elseif(isset($_srdvConfig['dateRemiseColis_jour']) && isset($_srdvConfig['dateRemiseColis_heures'])) {
                $jour_text = date('l', strtotime("Sunday +".$_srdvConfig['dateRemiseColis_jour']." days"));
                $dateBegin = date('Y-m-d', strtotime('next '.$jour_text)).' '.$_srdvConfig['dateRemiseColis_heures'].':'.$_srdvConfig['dateRemiseColis_minutes'].':00';
            }
            $dateBegin = date('Y-m-d',strtotime($dateBegin)).'T'.date('H:i:s',strtotime($dateBegin));

            $params = array(

                'callerTool' => 'RDVWS',
                'productType' => 'RDV',

                'shipperAdress1' => $_helper->getConfigurationShipperInfo('address1'),
                'shipperAdress2' => $_helper->getConfigurationShipperInfo('address2'),
                'shipperZipCode' => $_helper->getConfigurationShipperInfo('zipcode'),
                'shipperCity' => $_helper->getConfigurationShipperInfo('city'),
                'shipperCountry' => $_helper->getConfigurationShipperInfo('country'),

                'recipientAdress1' => substr($this->getFilledValue($recipient_address[0]), 0, 38),
                'recipientAdress2' => substr($this->getFilledValue($recipient_address[1]), 0, 38),
                'recipientZipCode' => $this->getFilledValue($_shippingAddress->getPostcode()),
                'recipientCity' => $this->getFilledValue($_shippingAddress->getCity()),
                'recipientCountry' => $this->getFilledValue($_shippingAddress->getCountryId()),

                'weight' => 1,
                'dateBegin' => $dateBegin,
                'shipperDeliverySlotClosed' => '',
                'currency' => 'EUR',
                'isDeliveryDate' => 0,
                'slotType' => 'J'
            );


            for($i = 1; $i <= 4; $i++) {

                /* tarif des niveaux tarifaires */
                if(isset($_srdvConfig['N'.$i.'_price'])) {
                    $params['rateN'.$i] = $_srdvConfig['N'.$i.'_price'];
                }

                /* niveaux tarifaires fermés  */
                if(isset($_srdvConfig['N'.$i.'_status']) && $_srdvConfig['N'.$i.'_status'] == 0) {
                    if(!isset($params['rateLevelsNotShow'])) {
                        $params['rateLevelsNotShow'] = array();
                    }
                    $params['rateLevelsNotShow'][]= 'N'.$i;
                }
            }

            /* creneaux à fermer */
            if(isset($_srdvConfig['creneaux'])) {
                foreach($_srdvConfig['creneaux'] as $_creneau) {

                    $jour_debut_text = date('l', Mage::getModel('core/date')->timestamp(strtotime("Sunday +".$_creneau['creneaux_debut_jour']." days")));
                    $jour_fin_text = date('l', Mage::getModel('core/date')->timestamp(strtotime("Sunday +".$_creneau['creneaux_fin_jour']." days")));

                    $dateDebut = '';
                    $dateFin = '';

                    /* creation de creneaux aux bons formats, pour 6 semaines consécutives */
                    for($indiceWeek = 0; $indiceWeek < 6; $indiceWeek++) {

                        if(empty($dateDebut)) {
                            $dateDebut = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime('next '.$jour_debut_text))).' '.(int)$_creneau['creneaux_debut_heures'].':'.(int)$_creneau['creneaux_debut_minutes'].':00';
                            $dateFin = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime('next '.$jour_fin_text))).' '.(int)$_creneau['creneaux_fin_heures'].':'.(int)$_creneau['creneaux_fin_minutes'].':00';
                            if(date('N') >= $_creneau['creneaux_debut_jour']) {
                                $dateDebut = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime(date('Y-m-d',strtotime($dateDebut)).' -7 day'))).' '.(int)$_creneau['creneaux_debut_heures'].':'.(int)$_creneau['creneaux_debut_minutes'].':00';
                            }
                            if(date('N') >= $_creneau['creneaux_fin_jour']) {
                                $dateFin = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime(date('Y-m-d',strtotime($dateFin)).' -7 day'))).' '.(int)$_creneau['creneaux_fin_heures'].':'.(int)$_creneau['creneaux_fin_minutes'].':00';
                            }

                        } else {
                            $dateDebut = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime($jour_debut_text.' next week '.date('Y-m-d',Mage::getModel('core/date')->timestamp(strtotime($dateDebut)))))).' '.(int)$_creneau['creneaux_debut_heures'].':'.(int)$_creneau['creneaux_debut_minutes'].':00';
                            $dateFin = date('Y-m-d', Mage::getModel('core/date')->timestamp(strtotime($jour_fin_text.' next week '.date('Y-m-d',Mage::getModel('core/date')->timestamp(strtotime($dateFin)))))).' '.(int)$_creneau['creneaux_fin_heures'].':'.(int)$_creneau['creneaux_fin_minutes'].':00';
                        }

                        $dateDebutStr = date('Y-m-d',Mage::getModel('core/date')->timestamp(strtotime($dateDebut))).'T'.date('H:i:s',Mage::getModel('core/date')->timestamp(strtotime($dateDebut)));
                        $dateFinStr = date('Y-m-d',Mage::getModel('core/date')->timestamp(strtotime($dateFin))).'T'.date('H:i:s',Mage::getModel('core/date')->timestamp(strtotime($dateFin)));

                        if(!isset($params['shipperDeliverySlotClosed'])) {
                            $params['shipperDeliverySlotClosed'] = array();
                        }
                        $params['shipperDeliverySlotClosed'][] = $dateDebutStr."/".$dateFinStr;
                    }
                }
            }

            $webservbt = $client->searchDeliverySlot($params);
            if($webservbt->return->code == 0) {
                return $webservbt;
            }
            return false;
        }catch(Exception $e) {
            return false;
        }
    }

    public function confirmDeliverySlot($rdvInfo = '') {
        $_helper = Mage::helper('food');
        try {

            $soapHeaders = array();
            $namespace = 'http://cxf.soap.ws.creneau.chronopost.fr/';
            $soapHeaders[] = new SoapHeader($namespace, 'password', $_helper->getConfigurationAccountPass());
            $soapHeaders[] = new SoapHeader($namespace, 'accountNumber', $_helper->getConfigurationAccountNumber());

            $client = new SoapClient("https://www.chronopost.fr/rdv-cxf/services/CreneauServiceWS?wsdl", array('trace' => 1, 'connection_timeout' => 10));
            $client->__setSoapHeaders($soapHeaders);

            $params = array(
                'callerTool' => 'RDVWS',
                'productType' => 'FRESH',

                'codeSlot' => $rdvInfo['deliverySlotCode'],
                'meshCode' => $rdvInfo['meshCode'],
                'transactionID' => $rdvInfo['transactionID'],
                'rank' => $rdvInfo['rank'],
                'position' => $rdvInfo['rank'],
                'dateSelected' => $rdvInfo['deliveryDate']
            );

            return $client->confirmDeliverySlot($params);
        }catch(Exception $e) {
            return false;
        }
    }
}
